summaryrefslogtreecommitdiff
path: root/sw/source
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2021-04-11 14:59:09 +0100
committerCaolán McNamara <caolanm@redhat.com>2021-04-11 19:40:40 +0200
commit3f9127d149492b572aebd32a3baee040b4c8d30b (patch)
tree1c1cc312b8d47c669787d73cbec9c2c32552ebaf /sw/source
parent77cb68db10cdd0dac9409cff0f59637b25e6d9a7 (diff)
ofz#26099 skip slow path when fuzzing
Change-Id: Idef5a50733bc4bdef45ea613b4833df0b9d7c9e0 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/113952 Tested-by: Jenkins Reviewed-by: Caolán McNamara <caolanm@redhat.com>
Diffstat (limited to 'sw/source')
-rw-r--r--sw/source/filter/html/htmltab.cxx23
1 files changed, 13 insertions, 10 deletions
diff --git a/sw/source/filter/html/htmltab.cxx b/sw/source/filter/html/htmltab.cxx
index a9e403e94519..b56a016e8d74 100644
--- a/sw/source/filter/html/htmltab.cxx
+++ b/sw/source/filter/html/htmltab.cxx
@@ -2291,16 +2291,19 @@ void HTMLTable::MakeTable( SwTableBox *pBox, sal_uInt16 nAbsAvail,
// Step 1: needed layout structures are created (including tables in tables)
CreateLayoutInfo();
- // Step 2: the minimal and maximal column width is calculated
- // (including tables in tables). Since we don't have boxes yet,
- // we'll work on the start nodes
- m_xLayoutInfo->AutoLayoutPass1();
-
- // Step 3: the actual column widths of this table are calculated (not tables in tables)
- // We need this now to decide if we need filler cells
- // (Pass1 was needed because of this as well)
- m_xLayoutInfo->AutoLayoutPass2( nAbsAvail, nRelAvail, nAbsLeftSpace,
- nAbsRightSpace, nInhAbsSpace );
+ if (!utl::ConfigManager::IsFuzzing()) // skip slow path for fuzzing
+ {
+ // Step 2: the minimal and maximal column width is calculated
+ // (including tables in tables). Since we don't have boxes yet,
+ // we'll work on the start nodes
+ m_xLayoutInfo->AutoLayoutPass1();
+
+ // Step 3: the actual column widths of this table are calculated (not tables in tables)
+ // We need this now to decide if we need filler cells
+ // (Pass1 was needed because of this as well)
+ m_xLayoutInfo->AutoLayoutPass2( nAbsAvail, nRelAvail, nAbsLeftSpace,
+ nAbsRightSpace, nInhAbsSpace );
+ }
// Set adjustment for the top table
sal_Int16 eHoriOri;